@@ -99,6 +99,11 @@ class SDApi(object):
         else:
             raise AttributeError(u'No method named %s' % (method,))
 
+        if request.status_code >= 400:
+            raise SDServiceError("An error with http status code %s "
+                                 "occurred." % (request.status_code,),
+                                 response=request.content)
+
         response = json.loads(request.content)
         if response['status'] == 2:
             raise SDServiceError(response['error']['message'],
